"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractFilePaths = exports.find = exports.stat = void 0;
const fs = require("fs");
const path_1 = require("path");
const util_1 = require("util");
const common_1 = require("./common");
const debug_1 = require("./debug");
const readdir = util_1.promisify(fs.readdir);
exports.stat = util_1.promisify(fs.stat);
async function find(dir) {
    const dirStat = await exports.stat(dir);
    if (!dirStat.isDirectory()) {
        throw new Error(`${dir} is not a directory`);
    }
    const paths = await readdir(dir);
    const absolutePaths = [];
    for (const relativePath of paths) {
        absolutePaths.push(path_1.join(dir, relativePath));
    }
    return await extractFilePaths(absolutePaths);
}
exports.find = find;
async function extractFilePaths(absolutePaths) {
    const result = [];
    for (const absolutePath of absolutePaths) {
        try {
            const fileStats = await exports.stat(absolutePath);
            if (fileStats.isDirectory()) {
                const subFiles = await find(absolutePath);
                result.push(...subFiles);
            }
            else if (fileStats.isFile()) {
                if (fileStats.size > common_1.MAX_SUPPORTED_FILE_SIZE) {
                    continue;
                }
                result.push(absolutePath);
            }
        }
        catch (error) {
            debug_1.debug(error.message || `Error reading file ${absolutePath}. ${error}`);
        }
    }
    return result;
}
exports.extractFilePaths = extractFilePaths;
//# sourceMappingURL=find.js.map